Enumeration
MalcontentAppFilterOarsValue
since: 0.2.0
Description [src]
Rating values of the intensity of a given section in an app or game.
These are directly equivalent to the values in the AsContentRatingValue
enumeration in libappstream.
Available since: 0.2.0
Members
-
MCT_APP_FILTER_OARS_VALUE_UNKNOWN -
Unknown value for the given section.
- Value:
0 - Available since: 0.2.0
- Value:
-
MCT_APP_FILTER_OARS_VALUE_NONE -
No rating for the given section.
- Value:
1 - Available since: 0.2.0
- Value:
-
MCT_APP_FILTER_OARS_VALUE_MILD -
Mild rating for the given section.
- Value:
2 - Available since: 0.2.0
- Value:
-
MCT_APP_FILTER_OARS_VALUE_MODERATE -
Moderate rating for the given section.
- Value:
3 - Available since: 0.2.0
- Value:
-
MCT_APP_FILTER_OARS_VALUE_INTENSE -
Intense rating for the given section.
- Value:
4 - Available since: 0.2.0
- Value: